@@ -39,12 +39,14 @@ import urllib.parse
 
 from reprotest.lib.system_interface.debian import DebianInterface
 from reprotest.lib.system_interface.arch import ArchInterface
+from reprotest.lib.system_interface.fedora import FedoraInterface
 from reprotest.lib import adtlog
 from reprotest.lib import VirtSubproc
 
 SYSTEM_INTERFACES = {
         'debian': DebianInterface,
-        'arch': ArchInterface
+        'arch': ArchInterface,
+        'fedora': FedoraInterface,
         }
 
 timeouts = {'short': 100, 'copy': 300, 'install': 3000, 'test': 10000,
